stop_tracing

Function stop_tracing 

pub fn stop_tracing()
Stop trace capture, flushing all buffered spans to the output file.

No-op if no session is active. After this call the trace file is complete and can be loaded into https://ui.perfetto.dev/.